@@ -1,4 +1,4 @@
-from .models import TestStorageTarget, TestFileStorageModel, TestImageStorageModel
+from .models import TestStorageTarget, TestFileStorageModel, TestImageStorageModel, TestEncryptedFileFieldModel, TestEncryptedImageFieldModel, get_fernet, gen_key
 import base64
 import json
 import os
@@ -14,7 +14,7 @@ from faker import Faker
 from functools import partial
 from django.core.files.base import ContentFile
 import logging
-import requests
+
 
 log = logging.getLogger(__name__)
 
@@ -118,7 +118,6 @@ def get_config(key, **kwargs):
 class TestStorageTargetFactory(factory.django.DjangoModelFactory):
     name = factory.LazyFunction(fake.catch_phrase)
     description = factory.LazyFunction(partial(fake.paragraph, 3))
-    created = factory.LazyFunction(fake.past_datetime)
     provider = factory.fuzzy.FuzzyChoice([x for x in STORAGE_PROVIDER_MAP.keys()], getter=lambda c: c)
     config = factory.LazyAttribute(lambda o: get_config(o.provider))
     last_status = factory.fuzzy.FuzzyChoice([x for x in LAST_STATUS_CHOICES], getter=lambda c: c[0])
@@ -139,13 +138,25 @@ class TestFileStorageModelFactory(factory.django.DjangoModelFactory):
         model = TestFileStorageModel
 
 
-def gen_image_file():
-    return ContentFile(requests.get(fake.image_url()).content, name=fake.file_name(extension='jpeg'))
-
-
 class TestImageStorageModelFactory(factory.django.DjangoModelFactory):
     storage_target = factory.SubFactory(TestStorageTargetFactory)
-    image = factory.django.FileField(from_func=gen_image_file)
+    image = factory.django.ImageField()
 
     class Meta:
         model = TestImageStorageModel
+
+
+class TestEncryptedFileFieldModelFactory(factory.django.DjangoModelFactory):
+    storage_target = factory.SubFactory(TestStorageTargetFactory)
+    file = factory.django.FileField(from_func=gen_file)
+
+    class Meta:
+        model = TestEncryptedFileFieldModel
+
+
+class TestEncryptedImageFieldModelFactory(factory.django.DjangoModelFactory):
+    storage_target = factory.SubFactory(TestStorageTargetFactory)
+    image = factory.django.ImageField()
+
+    class Meta:
+        model = TestEncryptedImageFieldModel
